#include "main_frame.h"

#define SET_BUTTON_ID	100
#define GET_BUTTON_ID	101

MainFrame::MainFrame()
	: wxFrame(nullptr, wxID_ANY, "RTC TESTER VIEW", wxPoint(0, 0), wxSize(800, 600))
{
	auto menuBar = new wxMenuBar;
	auto menuFile = new wxMenu;
	menuFile->Append(wxID_EXIT, wxT("Quit"));
	menuBar->Append(menuFile, wxT("&File"));
	SetMenuBar(menuBar);

	this->panel = new wxPanel(this, wxID_ANY);
	this->calendar_panel = new wxPanel(this->panel, wxID_ANY);
	this->time_panel = new wxPanel(this->panel, wxID_ANY);
	this->button_panel = new wxPanel(this->panel, wxID_ANY);

	this->set_button = new wxButton(this->button_panel, SET_BUTTON_ID, wxT("Set"));
	this->get_button = new wxButton(this->button_panel, GET_BUTTON_ID, wxT("Get"));

	this->calendar = new wxCalendarCtrl(this->calendar_panel, wxID_ANY, 
										wxDefaultDateTime,
                                    	wxDefaultPosition,
                                		wxSize(700, 400),
                                    	wxCAL_SHOW_HOLIDAYS);

	wxDateTime dt = wxDateTime::Now();
	this->time_picker_ctrl = new wxTimePickerCtrl(this->time_panel, wxID_ANY, dt, wxDefaultPosition, wxDefaultSize);
	wxStaticText *st = new wxStaticText(this->time_panel, wxID_ANY, wxT("Time"));

	wxBoxSizer *sizer = new wxBoxSizer(wxVERTICAL);
	sizer->AddStretchSpacer();
	sizer->Add(this->calendar_panel, 4, wxALIGN_CENTER | wxALL, 5);
	sizer->Add(this->time_panel, 1, wxEXPAND | wxALL);
	sizer->Add(this->button_panel, 1, wxEXPAND | wxALL);
	this->panel->SetSizer(sizer);

	wxBoxSizer *tpicker_ctrl_sizer = new wxBoxSizer(wxHORIZONTAL);
	tpicker_ctrl_sizer->Add(st, 0, wxRIGHT | wxALIGN_CENTER_VERTICAL, 10);
	tpicker_ctrl_sizer->Add(this->time_picker_ctrl, 0, wxRIGHT, 10);
	wxBoxSizer *tpicker_ctrl_base_sizer = new wxBoxSizer(wxVERTICAL);
	tpicker_ctrl_base_sizer->Add(tpicker_ctrl_sizer, 0, wxALIGN_CENTER);
	this->time_panel->SetSizer(tpicker_ctrl_base_sizer);

	wxBoxSizer *btn_sizer = new wxBoxSizer(wxHORIZONTAL);
	btn_sizer->Add(this->set_button, 0, wxRIGHT, 10);
	btn_sizer->Add(this->get_button, 0, wxRIGHT, 10);
	wxBoxSizer *btn_base_sizer = new wxBoxSizer(wxVERTICAL);
	btn_base_sizer->Add(btn_sizer, 0, wxALIGN_CENTER);
	this->button_panel->SetSizer(btn_base_sizer);

	this->panel->Layout();

	this->rtc_controller = new RTCController();

	Bind(wxEVT_CLOSE_WINDOW, &MainFrame::OnClose, this);
	Bind(wxEVT_MENU, [this](wxCommandEvent&) { Close(true); }, wxID_EXIT);
}

MainFrame::~MainFrame()
{
}

void MainFrame::OnClose(wxCloseEvent& event)
{
	Destroy();
}

void MainFrame::button_pressed(wxCommandEvent &event)
{
	struct tm tm;
	wxDateTime dt;
	int ret;

	memset(&tm, 0, sizeof(struct tm));
	if (event.GetId() == SET_BUTTON_ID) {
		dt = this->calendar->GetDate();
		tm.tm_year = dt.GetYear();
		tm.tm_mon = dt.GetMonth();
		tm.tm_mday = dt.GetDay();
		this->time_picker_ctrl->GetTime(&tm.tm_hour, &tm.tm_min, &tm.tm_sec);

		if (tm.tm_year < 2000 || 2099 < tm.tm_year) {
			wxLogError("Can not set date! invalid date.");
			return;
		}
		tm.tm_year -= 1900;

		this->rtc_controller->update_sysclk(&tm);
		ret = this->rtc_controller->rtc_write(&tm);
		if (ret < 0)
			wxLogError("failed set rtc (%d)", ret);
	} else {
		ret = this->rtc_controller->rtc_read(&tm);
		if (ret < 0) {
			wxLogError("failed get rtc (%d)", ret);
			return;
		}
		dt = wxDateTime(tm);
		this->calendar->SetDate(dt);
		this->time_picker_ctrl->SetTime(dt.GetHour(), dt.GetMinute(), dt.GetSecond());
	}
}

BEGIN_EVENT_TABLE(MainFrame, wxFrame)
	EVT_BUTTON(SET_BUTTON_ID, MainFrame::button_pressed)
	EVT_BUTTON(GET_BUTTON_ID, MainFrame::button_pressed)
END_EVENT_TABLE()
