import 'package:flutter/material.dart';
import 'package:flutter_demo_experience/provider.dart';
import 'package:flutter_demo_experience/widget/lang_button.dart';
import 'package:flutter_gen/gen_l10n/l10n.dart';
import 'package:flutter_demo_experience/widget/demo_source.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_demo_experience/const/colors.dart';
import 'package:flutter_demo_experience/const/dimens.dart';
import 'package:flutter_demo_experience/const/strings.dart';
import 'package:flutter_demo_experience/widget/demo_launch.dart';
import 'package:flutter_demo_experience/widget/demo_list.dart';
import 'package:flutter_demo_experience/widget/demo_title.dart';

void main() {
  runApp(const ProviderScope(child: MyApp()));
}

class MyApp extends ConsumerWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      localizationsDelegates: L10n.localizationsDelegates,
      supportedLocales: L10n.supportedLocales,
      locale: ref.watch(localeProvider),
      theme: ThemeData(
        primarySwatch: Colors.blue,
        fontFamily: 'IPAGothic',
      ),
      initialRoute: '/',
      routes: {'/': (context) => const MyHomePage()},
    );
  }
}

class MyHomePage extends ConsumerWidget {
  const MyHomePage({super.key});

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final Size deviceSize = MediaQuery.of(context).size;

    return Scaffold(
      extendBodyBehindAppBar: true,
      backgroundColor: bodyBackgroundColor,
      body: Column(
        children: [
          Stack(
            children: [
              DemoTitle(
                size: Size(
                    deviceSize.width, deviceSize.height * titleHeightRatio),
              ),
              const LangButton(names: langText),
            ],
          ),
          Expanded(
            child: Row(
              children: [
                DemoList(
                  size: Size(
                      deviceSize.width * demoListWidthRatio, deviceSize.height),
                ),
                const Expanded(
                  child: DemoLaunch(),
                ),
              ],
            ),
          ),
          const DemoSource(),
        ],
      ),
    );
  }
}
