import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:flutter_demo_experience/const/colors.dart';
import 'package:flutter_demo_experience/const/dimens.dart';
import 'package:flutter_demo_experience/const/strings.dart';
import 'package:flutter_demo_experience/provider.dart';

class DemoTitle extends ConsumerWidget {
  final Size size;
  const DemoTitle(
      {Key? key, this.size = const Size(double.infinity, double.infinity)})
      : super(key: key);

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final bool isExecutableDemo = ref.watch(isExecutableDemoProvider);

    return SizedBox(
      height: size.height,
      width: size.width,
      child: Stack(
        children: [
          Container(
            width: double.infinity,
            alignment: Alignment.center,
            color: headerBackgroundColor,
            child: Text(
              demoTitle,
              style: TextStyle(
                  fontSize: size.height * titleFontSizeRatio, color: textColor),
            ),
          ),
          if (ref.watch(demoRouteProvider).isNotEmpty)
            IconButton(
              onPressed: () {
                ref.watch(demoRouteProvider.notifier).update(
                  (route) {
                    route.removeLast();
                    // If you have clicked on a demo that is executable,
                    // the two previous routes will be the previous page.
                    if (isExecutableDemo) route.removeLast();
                    return [...route];
                  },
                );
                ref.watch(isExecutableDemoProvider.notifier).state = false;
              },
              iconSize: size.height * navigationPreviousItemSizeRatio,
              icon: SvgPicture.asset(
                'assets/images/navigation_previous_item.svg',
                color: textColor,
              ),
            ),
        ],
      ),
    );
  }
}
